@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 use Exporter 5.57 qw/import/;
 our @EXPORT_OK = qw/encode_geohex decode_geohex geohex_hexsize/;
 
@@ -18,8 +18,11 @@ sub new {
     elsif (exists $args{lat} and exists $args{lng} and exists $args{level}) {
         return $class->_new_with_latlng(@args{qw/lat lng level/});
     }
+    elsif (exists $args{x} and exists $args{y} and exists $args{level}) {
+        return $class->_new_with_latlng(@args{qw/x y level/});
+    }
     else {
-        die "Usage: $class->new(code => \$geohex_code) or $class->new(lat => \$lat, lng => \$lng, lng => \$level)";
+        die "Usage: $class->new(code => \$geohex_code) or $class->new(lat => \$lat, lng => \$lng, lng => \$level) or $class->new(x => \$x, y => \$y, lng => \$level)";
     }
 }
 
@@ -44,6 +47,10 @@ Geo::Hex::V3::XS - GeoHex implementation with XS. (c-geohex3 Perl5 binding.)
 
     my $zone = Geo::Hex::V3::XS->new(lat => 35.579826, lng => 139.654524, level => 9);
 
+    # or
+
+    my $zone = Geo::Hex::V3::XS->new(x => 11554, y => -3131, level => 7);
+
     say 'geohex.code:  ', $zone->code;
     say 'geohex.lat:   ', $zone->lat;
     say 'geohex.lng:   ', $zone->lng;
@@ -104,6 +111,18 @@ Create geohex zone object from location with level.
         level => 7,
     );
 
+=item * C<x/y/level>
+
+Create geohex zone object from coordinate with level.
+
+    use Geo::Hex::V3::XS;
+
+    my $zone = Geo::Hex::V3::XS->new(
+        x     => 11554,
+        y     => -3131,
+        level => 7,
+    );
+
 =back
 
 =item C<$zone-E<gt>lat>
@@ -114,6 +133,14 @@ Get geohex center location latitude.
 
 Get geohex center location longitude.
 
+=item C<$zone-E<gt>x>
+
+Get geohex center x coordinate.
+
+=item C<$zone-E<gt>y>
+
+Get geohex center y coordinate.
+
 =item C<$zone-E<gt>code>
 
 Get geohex code.
